@@ -13,6 +13,7 @@ import aiofiles
 from httpx import AsyncClient
 
 from meilisearch_python_async._http_requests import HttpRequests
+from meilisearch_python_async._utils import is_pydantic_2, iso_to_date_time
 from meilisearch_python_async.errors import InvalidDocumentError, MeilisearchError
 from meilisearch_python_async.models.documents import DocumentsInfo
 from meilisearch_python_async.models.index import IndexStats
@@ -54,8 +55,8 @@ class Index:
         """
         self.uid = uid
         self.primary_key = primary_key
-        self.created_at: datetime | None = _iso_to_date_time(created_at)
-        self.updated_at: datetime | None = _iso_to_date_time(updated_at)
+        self.created_at: datetime | None = iso_to_date_time(created_at)
+        self.updated_at: datetime | None = iso_to_date_time(updated_at)
         self._base_url = "indexes/"
         self._base_url_with_uid = f"{self._base_url}{self.uid}"
         self._documents_url = f"{self._base_url_with_uid}/documents"
@@ -113,7 +114,7 @@ class Index:
             >>>     await index.delete_if_exists()
         """
         response = await self.delete()
-        status = await wait_for_task(self.http_client, response.task_uid)
+        status = await wait_for_task(self.http_client, response.task_uid, timeout_in_ms=100000)
         if status.status == "succeeded":
             return True
 
@@ -175,10 +176,10 @@ class Index:
         self.primary_key = index_dict["primaryKey"]
         loop = get_running_loop()
         self.created_at = await loop.run_in_executor(
-            None, partial(_iso_to_date_time, index_dict["createdAt"])
+            None, partial(iso_to_date_time, index_dict["createdAt"])
         )
         self.updated_at = await loop.run_in_executor(
-            None, partial(_iso_to_date_time, index_dict["updatedAt"])
+            None, partial(iso_to_date_time, index_dict["updatedAt"])
         )
         return self
 
@@ -394,7 +395,12 @@ class Index:
         return response.json()
 
     async def get_documents(
-        self, *, offset: int = 0, limit: int = 20, fields: list[str] | None = None
+        self,
+        *,
+        offset: int = 0,
+        limit: int = 20,
+        fields: list[str] | None = None,
+        filter: str | list[str | list[str]] | None = None,
     ) -> DocumentsInfo:
         """Get a batch documents from the index.
 
@@ -404,6 +410,8 @@ class Index:
             limit: Maximum number of documents returnedd. Defaults to 20.
             fields: Document attributes to show. If this value is None then all
                 attributes are retrieved. Defaults to None.
+            filter: Filter value information. Defaults to None. Note: This parameter can only be
+                used with Meilisearch >= v1.2.0
 
         Returns:
 
@@ -427,11 +435,22 @@ class Index:
             "limit": limit,
         }
 
-        if fields:
-            parameters["fields"] = ",".join(fields)
+        if not filter:
+            if fields:
+                parameters["fields"] = ",".join(fields)
 
-        url = f"{self._documents_url}?{urlencode(parameters)}"
-        response = await self._http_requests.get(url)
+            url = f"{self._documents_url}?{urlencode(parameters)}"
+            response = await self._http_requests.get(url)
+
+            return DocumentsInfo(**response.json())
+
+        if fields:
+            parameters["fields"] = fields
+
+        parameters["filter"] = filter
+
+        url = f"{self._documents_url}/fetch"
+        response = await self._http_requests.post(url, body=parameters)
 
         return DocumentsInfo(**response.json())
 
@@ -1307,6 +1326,67 @@ class Index:
 
         return TaskInfo(**response.json())
 
+    async def delete_documents_by_filter(self, filter: str | list[str | list[str]]) -> TaskInfo:
+        """Delete documents from the index by filter.
+
+        Args:
+
+            filter: The filter value information.
+
+        Returns:
+
+            The details of the task status.
+
+        Raises:
+
+            MeilisearchCommunicationError: If there was an error communicating with the server.
+            MeilisearchApiError: If the Meilisearch API returned an error.
+
+        Examples:
+
+            >>> from meilisearch_python_async import Client
+            >>> async with Client("http://localhost.com", "masterKey") as client:
+            >>>     index = client.index("movies")
+            >>>     await index.delete_documents_by_filter("genre=horor"))
+        """
+        url = f"{self._documents_url}/delete"
+        response = await self._http_requests.post(url, body={"filter": filter})
+
+        return TaskInfo(**response.json())
+
+    async def delete_documents_in_batches_by_filter(
+        self, filters: list[str | list[str | list[str]]]
+    ) -> list[TaskInfo]:
+        """Delete batches of documents from the index by filter.
+
+        Args:
+
+            filters: A list of filter value information.
+
+        Returns:
+
+            The a list of details of the task statuses.
+
+        Raises:
+
+            MeilisearchCommunicationError: If there was an error communicating with the server.
+            MeilisearchApiError: If the Meilisearch API returned an error.
+
+        Examples:
+
+            >>> from meilisearch_python_async import Client
+            >>> async with Client("http://localhost.com", "masterKey") as client:
+            >>>     index = client.index("movies")
+            >>>     await index.delete_documents_in_batches_by_filter(
+            >>>         [
+            >>>             "genre=horor"),
+            >>>             "release_date=1520035200"),
+            >>>         ]
+            >>>     )
+        """
+        tasks = [self.delete_documents_by_filter(filter) for filter in filters]
+        return await gather(*tasks)
+
     async def delete_all_documents(self) -> TaskInfo:
         """Delete all documents from the index.
 
@@ -1398,7 +1478,10 @@ class Index:
             >>>     index = client.index("movies")
             >>>     await index.update_settings(new_settings)
         """
-        body_dict = {k: v for k, v in body.dict(by_alias=True).items() if v is not None}
+        if is_pydantic_2:
+            body_dict = {k: v for k, v in body.model_dump(by_alias=True).items() if v is not None}  # type: ignore[attr-defined]
+        else:  # pragma: no cover
+            body_dict = {k: v for k, v in body.dict(by_alias=True).items() if v is not None}  # type: ignore[attr-defined]
 
         url = f"{self._settings_url}"
         response = await self._http_requests.patch(url, body_dict)
@@ -2105,7 +2188,11 @@ class Index:
             >>>     await index.update_typo_tolerance()
         """
         url = f"{self._settings_url}/typo-tolerance"
-        response = await self._http_requests.patch(url, typo_tolerance.dict(by_alias=True))
+
+        if is_pydantic_2:
+            response = await self._http_requests.patch(url, typo_tolerance.model_dump(by_alias=True))  # type: ignore[attr-defined]
+        else:  # pragma: no cover
+            response = await self._http_requests.patch(url, typo_tolerance.dict(by_alias=True))  # type: ignore[attr-defined]
 
         return TaskInfo(**response.json())
 
@@ -2177,7 +2264,11 @@ class Index:
             >>>     await index.update_faceting(faceting=Faceting(max_values_per_facet=100))
         """
         url = f"{self._settings_url}/faceting"
-        response = await self._http_requests.patch(url, faceting.dict(by_alias=True))
+
+        if is_pydantic_2:
+            response = await self._http_requests.patch(url, faceting.model_dump(by_alias=True))  # type: ignore[attr-defined]
+        else:  # pragma: no cover
+            response = await self._http_requests.patch(url, faceting.dict(by_alias=True))  # type: ignore[attr-defined]
 
         return TaskInfo(**response.json())
 
@@ -2250,7 +2341,11 @@ class Index:
             >>>     await index.update_pagination(settings=Pagination(max_total_hits=123))
         """
         url = f"{self._settings_url}/pagination"
-        response = await self._http_requests.patch(url, settings.dict(by_alias=True))
+
+        if is_pydantic_2:
+            response = await self._http_requests.patch(url, settings.model_dump(by_alias=True))  # type: ignore[attr-defined]
+        else:  # pragma: no cover
+            response = await self._http_requests.patch(url, settings.dict(by_alias=True))  # type: ignore[attr-defined]
 
         return TaskInfo(**response.json())
 
@@ -2296,27 +2391,6 @@ def _combine_documents(documents: list[list[Any]]) -> list[Any]:
     return [x for y in documents for x in y]
 
 
-def _iso_to_date_time(iso_date: datetime | str | None) -> datetime | None:
-    """Handle conversion of iso string to datetime.
-
-    The microseconds from Meilisearch are sometimes too long for python to convert so this
-    strips off the last digits to shorten it when that happens.
-    """
-    if not iso_date:
-        return None
-
-    if isinstance(iso_date, datetime):
-        return iso_date
-
-    try:
-        return datetime.strptime(iso_date, "%Y-%m-%dT%H:%M:%S.%fZ")
-    except ValueError:
-        split = iso_date.split(".")
-        reduce = len(split[1]) - 6
-        reduced = f"{split[0]}.{split[1][:-reduce]}Z"
-        return datetime.strptime(reduced, "%Y-%m-%dT%H:%M:%S.%fZ")
-
-
 async def _load_documents_from_file(
     file_path: Path | str,
     csv_delimiter: str | None = None,
@@ -2335,7 +2409,7 @@ async def _load_documents_from_file(
             and not csv_delimiter.isascii()
         ):
             raise ValueError("csv_delimiter must be a single ascii character")
-        with open(file_path, mode="r") as f:
+        with open(file_path) as f:
             if csv_delimiter:
                 documents = await loop.run_in_executor(
                     None, partial(DictReader, f, delimiter=csv_delimiter)
@@ -2345,7 +2419,7 @@ async def _load_documents_from_file(
             return list(documents)
 
     if file_path.suffix == ".ndjson":
-        with open(file_path, mode="r") as f:
+        with open(file_path) as f:
             return [await loop.run_in_executor(None, partial(json.loads, x)) for x in f]
 
     async with aiofiles.open(file_path, mode="r") as f:  # type: ignore
